==> cachettl-1.0.1.tar.gz: cachettl-1.0.1/setup.py <==
import codecs
from setuptools import setup, find_packages

setup(
    name='cachettl',
    version='1.0.1',
    description='cachettl is an elegant LRU TTL Cache decorator with methods cache_info(), cache_clear() and a property remainingttl',
    url='https://github.com/rabuchaim/cachettl',
    author='Ricardo Abuchaim',
    author_email='ricardoabuchaim@gmail.com',
    maintainer='Ricardo Abuchaim',
    maintainer_email='ricardoabuchaim@gmail.com',
    project_urls={
        "Issue Tracker": "https://github.com/rabuchaim/cachettl/issues",
        "Source code": "https://github.com/rabuchaim/cachettl",
    },    
    bugtrack_url='https://github.com/rabuchaim/cachettl/issues',    
    license='MIT',
    keywords=['cachettl','cache_ttl','ttlcache','functools','lrucache','lru_cache','cache','pure-python','purepython','pure python'],
    packages=['cachettl'],
    py_modules=['cachettl'],
    package_dir = {'cachettl': 'cachettl'},
    include_package_data=True,
    zip_safe = False,
    package_data={
        'cachettl': [
            'example.py',
            'cachettl/__init__.py',
            'cachettl/cachettl.py',
        ],
    },
    python_requires=">=3.7",
    install_requires=[],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities',
        'Intended Audience :: Developers',
        'Intended Audience :: Information Technology',
        'Intended Audience :: System Administrators',
        'Operating System :: MacOS',
        'Operating System :: Microsoft :: Windows :: Windows 10',
        'Operating System :: Microsoft :: Windows :: Windows 11',
        'Operating System :: Unix',
        'Operating System :: POSIX',
        'Operating System :: POSIX :: Linux',
        'Operating System :: POSIX :: BSD',
        'Operating System :: POSIX :: BSD :: FreeBSD',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',  
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'Programming Language :: Python :: 3.13',
        'Programming Language :: Python :: Implementation :: PyPy',
        'License :: OSI Approved :: MIT License',
    ],
    long_description=codecs.open("README.md","r","utf-8").read(),
    long_description_content_type='text/markdown',
)

==> cachettl-1.0.2.tar.gz: cachettl-1.0.2/setup.py <==
import codecs
from setuptools import setup, find_packages

setup(
    name='cachettl',
    version='1.0.2',
    description='cachettl is an elegant LRU TTL cache decorator that also works with asyncio. It has the cache_info(), cache_clear() methods and access to the remainingttl property.',
    url='https://github.com/rabuchaim/cachettl',
    author='Ricardo Abuchaim',
    author_email='ricardoabuchaim@gmail.com',
    maintainer='Ricardo Abuchaim',
    maintainer_email='ricardoabuchaim@gmail.com',
    project_urls={
        "Issue Tracker": "https://github.com/rabuchaim/cachettl/issues",
        "Source code": "https://github.com/rabuchaim/cachettl",
    },    
    bugtrack_url='https://github.com/rabuchaim/cachettl/issues',    
    license='MIT',
    keywords=['cachettl','cache_ttl','ttlcache','async cache ttl','async_cachettl','functools','lrucache','lru_cache','cache','pure-python','purepython','pure python'],
    packages=['cachettl'],
    py_modules=['cachettl'],
    package_dir = {'cachettl': 'cachettl'},
    include_package_data=True,
    zip_safe = False,
    package_data={
        'cachettl': [
            'example.py',
            'example_async.py',
            'cachettl/__init__.py',
            'cachettl/cachettl.py',
        ],
    },
    python_requires=">=3.7",
    install_requires=[],
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities',
        'Intended Audience :: Developers',
        'Intended Audience :: Information Technology',
        'Intended Audience :: System Administrators',
        'Operating System :: MacOS',
        'Operating System :: Microsoft :: Windows :: Windows 10',
        'Operating System :: Microsoft :: Windows :: Windows 11',
        'Operating System :: Unix',
        'Operating System :: POSIX',
        'Operating System :: POSIX :: Linux',
        'Operating System :: POSIX :: BSD',
        'Operating System :: POSIX :: BSD :: FreeBSD',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',  
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'Programming Language :: Python :: 3.13',
        'Programming Language :: Python :: Implementation :: PyPy',
        'License :: OSI Approved :: MIT License',
    ],
    long_description=codecs.open("README.md","r","utf-8").read(),
    long_description_content_type='text/markdown',
)
